# Generated from NmrViewPKParser.g4 by ANTLR 4.13.0
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,33,427,2,0,7,0,2,1,7,1,2,2,7,2,2,3,7,3,2,4,7,4,2,5,7,5,2,6,7,
        6,2,7,7,7,2,8,7,8,2,9,7,9,2,10,7,10,2,11,7,11,2,12,7,12,2,13,7,13,
        2,14,7,14,2,15,7,15,2,16,7,16,1,0,3,0,36,8,0,1,0,1,0,1,0,1,0,1,0,
        1,0,1,0,5,0,45,8,0,10,0,12,0,48,9,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,
        1,1,1,1,1,1,4,1,60,8,1,11,1,12,1,61,1,1,1,1,1,1,1,1,1,1,1,1,1,2,
        4,2,71,8,2,11,2,12,2,72,1,3,1,3,1,3,1,3,1,3,1,3,1,3,1,3,1,3,1,3,
        1,3,1,3,1,3,1,3,1,3,1,3,1,3,1,3,3,3,93,8,3,1,3,1,3,3,3,97,8,3,1,
        3,4,3,100,8,3,11,3,12,3,101,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,
        1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,3,4,123,8,4,1,4,1,4,1,4,
        1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,
        1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,1,5,3,5,153,8,5,1,5,1,5,3,5,157,
        8,5,1,5,4,5,160,8,5,11,5,12,5,161,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,
        6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,
        6,1,6,1,6,3,6,190,8,6,1,6,1,6,1,6,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,
        7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,
        7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,1,7,3,7,227,8,7,1,7,1,7,3,7,231,8,
        7,1,7,4,7,234,8,7,11,7,12,7,235,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,
        1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,
        1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,3,8,271,8,8,1,8,1,8,1,8,1,9,
        1,9,1,9,1,9,1,9,1,9,1,9,1,9,1,9,1,9,1,9,1,9,3,9,288,8,9,1,9,1,9,
        3,9,292,8,9,1,9,4,9,295,8,9,11,9,12,9,296,1,10,1,10,1,10,1,10,1,
        10,1,10,1,10,1,10,1,10,1,10,1,10,1,10,1,10,3,10,312,8,10,1,10,1,
        10,1,10,1,11,1,11,1,11,1,11,1,11,1,11,1,11,1,11,1,11,1,11,1,11,1,
        11,1,11,1,11,1,11,1,11,3,11,333,8,11,1,11,1,11,3,11,337,8,11,1,11,
        4,11,340,8,11,11,11,12,11,341,1,12,1,12,1,12,1,12,1,12,1,12,1,12,
        1,12,1,12,1,12,1,12,1,12,1,12,1,12,1,12,1,12,1,12,3,12,361,8,12,
        1,12,1,12,1,12,1,13,1,13,1,13,1,13,1,13,1,13,1,13,1,13,1,13,1,13,
        1,13,1,13,1,13,1,13,1,13,1,13,1,13,1,13,1,13,1,13,3,13,386,8,13,
        1,13,1,13,3,13,390,8,13,1,13,4,13,393,8,13,11,13,12,13,394,1,14,
        1,14,1,14,1,14,1,14,1,14,1,14,1,14,1,14,1,14,1,14,1,14,1,14,1,14,
        1,14,1,14,1,14,1,14,1,14,1,14,1,14,3,14,418,8,14,1,14,1,14,1,14,
        1,15,1,15,1,16,1,16,1,16,0,0,17,0,2,4,6,8,10,12,14,16,18,20,22,24,
        26,28,30,32,0,2,2,0,29,30,33,33,3,0,3,3,8,8,11,11,443,0,35,1,0,0,
        0,2,51,1,0,0,0,4,70,1,0,0,0,6,74,1,0,0,0,8,103,1,0,0,0,10,127,1,
        0,0,0,12,163,1,0,0,0,14,194,1,0,0,0,16,237,1,0,0,0,18,275,1,0,0,
        0,20,298,1,0,0,0,22,316,1,0,0,0,24,343,1,0,0,0,26,365,1,0,0,0,28,
        396,1,0,0,0,30,422,1,0,0,0,32,424,1,0,0,0,34,36,5,10,0,0,35,34,1,
        0,0,0,35,36,1,0,0,0,36,46,1,0,0,0,37,45,3,2,1,0,38,45,3,6,3,0,39,
        45,3,10,5,0,40,45,3,14,7,0,41,45,3,18,9,0,42,45,3,22,11,0,43,45,
        3,26,13,0,44,37,1,0,0,0,44,38,1,0,0,0,44,39,1,0,0,0,44,40,1,0,0,
        0,44,41,1,0,0,0,44,42,1,0,0,0,44,43,1,0,0,0,45,48,1,0,0,0,46,44,
        1,0,0,0,46,47,1,0,0,0,47,49,1,0,0,0,48,46,1,0,0,0,49,50,5,0,0,1,
        50,1,1,0,0,0,51,52,5,1,0,0,52,53,5,14,0,0,53,54,5,15,0,0,54,55,5,
        16,0,0,55,56,5,32,0,0,56,57,3,4,2,0,57,59,5,32,0,0,58,60,5,29,0,
        0,59,58,1,0,0,0,60,61,1,0,0,0,61,59,1,0,0,0,61,62,1,0,0,0,62,63,
        1,0,0,0,63,64,5,32,0,0,64,65,3,4,2,0,65,66,5,32,0,0,66,67,3,4,2,
        0,67,68,5,32,0,0,68,3,1,0,0,0,69,71,3,30,15,0,70,69,1,0,0,0,71,72,
        1,0,0,0,72,70,1,0,0,0,72,73,1,0,0,0,73,5,1,0,0,0,74,75,5,17,0,0,
        75,76,5,18,0,0,76,77,5,19,0,0,77,78,5,20,0,0,78,79,5,21,0,0,79,80,
        5,22,0,0,80,81,5,23,0,0,81,82,5,17,0,0,82,83,5,18,0,0,83,84,5,19,
        0,0,84,85,5,20,0,0,85,86,5,21,0,0,86,87,5,22,0,0,87,88,5,23,0,0,
        88,89,5,24,0,0,89,90,5,25,0,0,90,92,5,26,0,0,91,93,5,27,0,0,92,91,
        1,0,0,0,92,93,1,0,0,0,93,94,1,0,0,0,94,96,5,28,0,0,95,97,5,10,0,
        0,96,95,1,0,0,0,96,97,1,0,0,0,97,99,1,0,0,0,98,100,3,8,4,0,99,98,
        1,0,0,0,100,101,1,0,0,0,101,99,1,0,0,0,101,102,1,0,0,0,102,7,1,0,
        0,0,103,104,5,2,0,0,104,105,5,11,0,0,105,106,5,3,0,0,106,107,5,3,
        0,0,107,108,5,3,0,0,108,109,5,8,0,0,109,110,3,32,16,0,110,111,5,
        11,0,0,111,112,5,11,0,0,112,113,5,3,0,0,113,114,5,3,0,0,114,115,
        5,3,0,0,115,116,5,8,0,0,116,117,3,32,16,0,117,118,5,11,0,0,118,119,
        5,3,0,0,119,120,5,3,0,0,120,122,5,2,0,0,121,123,5,11,0,0,122,121,
        1,0,0,0,122,123,1,0,0,0,123,124,1,0,0,0,124,125,5,2,0,0,125,126,
        5,10,0,0,126,9,1,0,0,0,127,128,5,17,0,0,128,129,5,18,0,0,129,130,
        5,19,0,0,130,131,5,20,0,0,131,132,5,21,0,0,132,133,5,22,0,0,133,
        134,5,23,0,0,134,135,5,17,0,0,135,136,5,18,0,0,136,137,5,19,0,0,
        137,138,5,20,0,0,138,139,5,21,0,0,139,140,5,22,0,0,140,141,5,23,
        0,0,141,142,5,17,0,0,142,143,5,18,0,0,143,144,5,19,0,0,144,145,5,
        20,0,0,145,146,5,21,0,0,146,147,5,22,0,0,147,148,5,23,0,0,148,149,
        5,24,0,0,149,150,5,25,0,0,150,152,5,26,0,0,151,153,5,27,0,0,152,
        151,1,0,0,0,152,153,1,0,0,0,153,154,1,0,0,0,154,156,5,28,0,0,155,
        157,5,10,0,0,156,155,1,0,0,0,156,157,1,0,0,0,157,159,1,0,0,0,158,
        160,3,12,6,0,159,158,1,0,0,0,160,161,1,0,0,0,161,159,1,0,0,0,161,
        162,1,0,0,0,162,11,1,0,0,0,163,164,5,2,0,0,164,165,5,11,0,0,165,
        166,5,3,0,0,166,167,5,3,0,0,167,168,5,3,0,0,168,169,5,8,0,0,169,
        170,3,32,16,0,170,171,5,11,0,0,171,172,5,11,0,0,172,173,5,3,0,0,
        173,174,5,3,0,0,174,175,5,3,0,0,175,176,5,8,0,0,176,177,3,32,16,
        0,177,178,5,11,0,0,178,179,5,11,0,0,179,180,5,3,0,0,180,181,5,3,
        0,0,181,182,5,3,0,0,182,183,5,8,0,0,183,184,3,32,16,0,184,185,5,
        11,0,0,185,186,5,3,0,0,186,187,5,3,0,0,187,189,5,2,0,0,188,190,5,
        11,0,0,189,188,1,0,0,0,189,190,1,0,0,0,190,191,1,0,0,0,191,192,5,
        2,0,0,192,193,5,10,0,0,193,13,1,0,0,0,194,195,5,17,0,0,195,196,5,
        18,0,0,196,197,5,19,0,0,197,198,5,20,0,0,198,199,5,21,0,0,199,200,
        5,22,0,0,200,201,5,23,0,0,201,202,5,17,0,0,202,203,5,18,0,0,203,
        204,5,19,0,0,204,205,5,20,0,0,205,206,5,21,0,0,206,207,5,22,0,0,
        207,208,5,23,0,0,208,209,5,17,0,0,209,210,5,18,0,0,210,211,5,19,
        0,0,211,212,5,20,0,0,212,213,5,21,0,0,213,214,5,22,0,0,214,215,5,
        23,0,0,215,216,5,17,0,0,216,217,5,18,0,0,217,218,5,19,0,0,218,219,
        5,20,0,0,219,220,5,21,0,0,220,221,5,22,0,0,221,222,5,23,0,0,222,
        223,5,24,0,0,223,224,5,25,0,0,224,226,5,26,0,0,225,227,5,27,0,0,
        226,225,1,0,0,0,226,227,1,0,0,0,227,228,1,0,0,0,228,230,5,28,0,0,
        229,231,5,10,0,0,230,229,1,0,0,0,230,231,1,0,0,0,231,233,1,0,0,0,
        232,234,3,16,8,0,233,232,1,0,0,0,234,235,1,0,0,0,235,233,1,0,0,0,
        235,236,1,0,0,0,236,15,1,0,0,0,237,238,5,2,0,0,238,239,5,11,0,0,
        239,240,5,3,0,0,240,241,5,3,0,0,241,242,5,3,0,0,242,243,5,8,0,0,
        243,244,3,32,16,0,244,245,5,11,0,0,245,246,5,11,0,0,246,247,5,3,
        0,0,247,248,5,3,0,0,248,249,5,3,0,0,249,250,5,8,0,0,250,251,3,32,
        16,0,251,252,5,11,0,0,252,253,5,11,0,0,253,254,5,3,0,0,254,255,5,
        3,0,0,255,256,5,3,0,0,256,257,5,8,0,0,257,258,3,32,16,0,258,259,
        5,11,0,0,259,260,5,11,0,0,260,261,5,3,0,0,261,262,5,3,0,0,262,263,
        5,3,0,0,263,264,5,8,0,0,264,265,3,32,16,0,265,266,5,11,0,0,266,267,
        5,3,0,0,267,268,5,3,0,0,268,270,5,2,0,0,269,271,5,11,0,0,270,269,
        1,0,0,0,270,271,1,0,0,0,271,272,1,0,0,0,272,273,5,2,0,0,273,274,
        5,10,0,0,274,17,1,0,0,0,275,276,5,17,0,0,276,277,5,18,0,0,277,278,
        5,19,0,0,278,279,5,20,0,0,279,280,5,17,0,0,280,281,5,18,0,0,281,
        282,5,19,0,0,282,283,5,20,0,0,283,284,5,24,0,0,284,285,5,25,0,0,
        285,287,5,26,0,0,286,288,5,27,0,0,287,286,1,0,0,0,287,288,1,0,0,
        0,288,289,1,0,0,0,289,291,5,28,0,0,290,292,5,10,0,0,291,290,1,0,
        0,0,291,292,1,0,0,0,292,294,1,0,0,0,293,295,3,20,10,0,294,293,1,
        0,0,0,295,296,1,0,0,0,296,294,1,0,0,0,296,297,1,0,0,0,297,19,1,0,
        0,0,298,299,5,2,0,0,299,300,5,11,0,0,300,301,5,3,0,0,301,302,5,3,
        0,0,302,303,5,3,0,0,303,304,5,11,0,0,304,305,5,3,0,0,305,306,5,3,
        0,0,306,307,5,3,0,0,307,308,5,3,0,0,308,309,5,3,0,0,309,311,5,2,
        0,0,310,312,5,11,0,0,311,310,1,0,0,0,311,312,1,0,0,0,312,313,1,0,
        0,0,313,314,5,2,0,0,314,315,5,10,0,0,315,21,1,0,0,0,316,317,5,17,
        0,0,317,318,5,18,0,0,318,319,5,19,0,0,319,320,5,20,0,0,320,321,5,
        17,0,0,321,322,5,18,0,0,322,323,5,19,0,0,323,324,5,20,0,0,324,325,
        5,17,0,0,325,326,5,18,0,0,326,327,5,19,0,0,327,328,5,20,0,0,328,
        329,5,24,0,0,329,330,5,25,0,0,330,332,5,26,0,0,331,333,5,27,0,0,
        332,331,1,0,0,0,332,333,1,0,0,0,333,334,1,0,0,0,334,336,5,28,0,0,
        335,337,5,10,0,0,336,335,1,0,0,0,336,337,1,0,0,0,337,339,1,0,0,0,
        338,340,3,24,12,0,339,338,1,0,0,0,340,341,1,0,0,0,341,339,1,0,0,
        0,341,342,1,0,0,0,342,23,1,0,0,0,343,344,5,2,0,0,344,345,5,11,0,
        0,345,346,5,3,0,0,346,347,5,3,0,0,347,348,5,3,0,0,348,349,5,11,0,
        0,349,350,5,3,0,0,350,351,5,3,0,0,351,352,5,3,0,0,352,353,5,11,0,
        0,353,354,5,3,0,0,354,355,5,3,0,0,355,356,5,3,0,0,356,357,5,3,0,
        0,357,358,5,3,0,0,358,360,5,2,0,0,359,361,5,11,0,0,360,359,1,0,0,
        0,360,361,1,0,0,0,361,362,1,0,0,0,362,363,5,2,0,0,363,364,5,10,0,
        0,364,25,1,0,0,0,365,366,5,17,0,0,366,367,5,18,0,0,367,368,5,19,
        0,0,368,369,5,20,0,0,369,370,5,17,0,0,370,371,5,18,0,0,371,372,5,
        19,0,0,372,373,5,20,0,0,373,374,5,17,0,0,374,375,5,18,0,0,375,376,
        5,19,0,0,376,377,5,20,0,0,377,378,5,17,0,0,378,379,5,18,0,0,379,
        380,5,19,0,0,380,381,5,20,0,0,381,382,5,24,0,0,382,383,5,25,0,0,
        383,385,5,26,0,0,384,386,5,27,0,0,385,384,1,0,0,0,385,386,1,0,0,
        0,386,387,1,0,0,0,387,389,5,28,0,0,388,390,5,10,0,0,389,388,1,0,
        0,0,389,390,1,0,0,0,390,392,1,0,0,0,391,393,3,28,14,0,392,391,1,
        0,0,0,393,394,1,0,0,0,394,392,1,0,0,0,394,395,1,0,0,0,395,27,1,0,
        0,0,396,397,5,2,0,0,397,398,5,11,0,0,398,399,5,3,0,0,399,400,5,3,
        0,0,400,401,5,3,0,0,401,402,5,11,0,0,402,403,5,3,0,0,403,404,5,3,
        0,0,404,405,5,3,0,0,405,406,5,11,0,0,406,407,5,3,0,0,407,408,5,3,
        0,0,408,409,5,3,0,0,409,410,5,11,0,0,410,411,5,3,0,0,411,412,5,3,
        0,0,412,413,5,3,0,0,413,414,5,3,0,0,414,415,5,3,0,0,415,417,5,2,
        0,0,416,418,5,11,0,0,417,416,1,0,0,0,417,418,1,0,0,0,418,419,1,0,
        0,0,419,420,5,2,0,0,420,421,5,10,0,0,421,29,1,0,0,0,422,423,7,0,
        0,0,423,31,1,0,0,0,424,425,7,1,0,0,425,33,1,0,0,0,29,35,44,46,61,
        72,92,96,101,122,152,156,161,189,226,230,235,270,287,291,296,311,
        332,336,341,360,385,389,394,417
    ]

class NmrViewPKParser ( Parser ):

    grammarFileName = "NmrViewPKParser.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "'label'", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "'dataset'", "'sw'", "'sf'", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "'vol'", "'int'", "'stat'", 
                     "'comment'" ]

    symbolicNames = [ "<INVALID>", "Label", "Integer", "Float", "Real", 
                      "SHARP_COMMENT", "EXCLM_COMMENT", "SMCLN_COMMENT", 
                      "Simple_name", "SPACE", "RETURN", "ENCLOSE_DATA", 
                      "SECTION_COMMENT", "LINE_COMMENT", "Dataset", "Sw", 
                      "Sf", "L_name", "P_name", "W_name", "B_name", "E_name", 
                      "J_name", "U_name", "Vol", "Int", "Stat", "Comment", 
                      "Flag0", "Simple_name_LA", "Float_LA", "SPACE_LA", 
                      "RETURN_LA", "ENCLOSE_DATA_LA" ]

    RULE_nmrview_pk = 0
    RULE_data_label = 1
    RULE_labels = 2
    RULE_peak_list_2d = 3
    RULE_peak_2d = 4
    RULE_peak_list_3d = 5
    RULE_peak_3d = 6
    RULE_peak_list_4d = 7
    RULE_peak_4d = 8
    RULE_peak_list_wo_eju_2d = 9
    RULE_peak_wo_eju_2d = 10
    RULE_peak_list_wo_eju_3d = 11
    RULE_peak_wo_eju_3d = 12
    RULE_peak_list_wo_eju_4d = 13
    RULE_peak_wo_eju_4d = 14
    RULE_label = 15
    RULE_jcoupling = 16

    ruleNames =  [ "nmrview_pk", "data_label", "labels", "peak_list_2d", 
                   "peak_2d", "peak_list_3d", "peak_3d", "peak_list_4d", 
                   "peak_4d", "peak_list_wo_eju_2d", "peak_wo_eju_2d", "peak_list_wo_eju_3d", 
                   "peak_wo_eju_3d", "peak_list_wo_eju_4d", "peak_wo_eju_4d", 
                   "label", "jcoupling" ]

    EOF = Token.EOF
    Label=1
    Integer=2
    Float=3
    Real=4
    SHARP_COMMENT=5
    EXCLM_COMMENT=6
    SMCLN_COMMENT=7
    Simple_name=8
    SPACE=9
    RETURN=10
    ENCLOSE_DATA=11
    SECTION_COMMENT=12
    LINE_COMMENT=13
    Dataset=14
    Sw=15
    Sf=16
    L_name=17
    P_name=18
    W_name=19
    B_name=20
    E_name=21
    J_name=22
    U_name=23
    Vol=24
    Int=25
    Stat=26
    Comment=27
    Flag0=28
    Simple_name_LA=29
    Float_LA=30
    SPACE_LA=31
    RETURN_LA=32
    ENCLOSE_DATA_LA=33

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.13.0")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class Nmrview_pkContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EOF(self):
            return self.getToken(NmrViewPKParser.EOF, 0)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def data_label(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Data_labelContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Data_labelContext,i)


        def peak_list_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_list_2dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_list_2dContext,i)


        def peak_list_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_list_3dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_list_3dContext,i)


        def peak_list_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_list_4dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_list_4dContext,i)


        def peak_list_wo_eju_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_list_wo_eju_2dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_list_wo_eju_2dContext,i)


        def peak_list_wo_eju_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_list_wo_eju_3dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_list_wo_eju_3dContext,i)


        def peak_list_wo_eju_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_list_wo_eju_4dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_list_wo_eju_4dContext,i)


        def getRuleIndex(self):
            return NmrViewPKParser.RULE_nmrview_pk

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNmrview_pk" ):
                listener.enterNmrview_pk(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNmrview_pk" ):
                listener.exitNmrview_pk(self)




    def nmrview_pk(self):

        localctx = NmrViewPKParser.Nmrview_pkContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_nmrview_pk)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 35
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 34
                self.match(NmrViewPKParser.RETURN)


            self.state = 46
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==1 or _la==17:
                self.state = 44
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,1,self._ctx)
                if la_ == 1:
                    self.state = 37
                    self.data_label()
                    pass

                elif la_ == 2:
                    self.state = 38
                    self.peak_list_2d()
                    pass

                elif la_ == 3:
                    self.state = 39
                    self.peak_list_3d()
                    pass

                elif la_ == 4:
                    self.state = 40
                    self.peak_list_4d()
                    pass

                elif la_ == 5:
                    self.state = 41
                    self.peak_list_wo_eju_2d()
                    pass

                elif la_ == 6:
                    self.state = 42
                    self.peak_list_wo_eju_3d()
                    pass

                elif la_ == 7:
                    self.state = 43
                    self.peak_list_wo_eju_4d()
                    pass


                self.state = 48
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 49
            self.match(NmrViewPKParser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Data_labelContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Label(self):
            return self.getToken(NmrViewPKParser.Label, 0)

        def Dataset(self):
            return self.getToken(NmrViewPKParser.Dataset, 0)

        def Sw(self):
            return self.getToken(NmrViewPKParser.Sw, 0)

        def Sf(self):
            return self.getToken(NmrViewPKParser.Sf, 0)

        def RETURN_LA(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.RETURN_LA)
            else:
                return self.getToken(NmrViewPKParser.RETURN_LA, i)

        def labels(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.LabelsContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.LabelsContext,i)


        def Simple_name_LA(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Simple_name_LA)
            else:
                return self.getToken(NmrViewPKParser.Simple_name_LA, i)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_data_label

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterData_label" ):
                listener.enterData_label(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitData_label" ):
                listener.exitData_label(self)




    def data_label(self):

        localctx = NmrViewPKParser.Data_labelContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_data_label)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 51
            self.match(NmrViewPKParser.Label)
            self.state = 52
            self.match(NmrViewPKParser.Dataset)
            self.state = 53
            self.match(NmrViewPKParser.Sw)
            self.state = 54
            self.match(NmrViewPKParser.Sf)
            self.state = 55
            self.match(NmrViewPKParser.RETURN_LA)
            self.state = 56
            self.labels()
            self.state = 57
            self.match(NmrViewPKParser.RETURN_LA)
            self.state = 59 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 58
                self.match(NmrViewPKParser.Simple_name_LA)
                self.state = 61 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==29):
                    break

            self.state = 63
            self.match(NmrViewPKParser.RETURN_LA)
            self.state = 64
            self.labels()
            self.state = 65
            self.match(NmrViewPKParser.RETURN_LA)
            self.state = 66
            self.labels()
            self.state = 67
            self.match(NmrViewPKParser.RETURN_LA)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LabelsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def label(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.LabelContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.LabelContext,i)


        def getRuleIndex(self):
            return NmrViewPKParser.RULE_labels

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLabels" ):
                listener.enterLabels(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLabels" ):
                listener.exitLabels(self)




    def labels(self):

        localctx = NmrViewPKParser.LabelsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_labels)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 70 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 69
                self.label()
                self.state = 72 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & 10200547328) != 0)):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def L_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.L_name)
            else:
                return self.getToken(NmrViewPKParser.L_name, i)

        def P_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.P_name)
            else:
                return self.getToken(NmrViewPKParser.P_name, i)

        def W_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.W_name)
            else:
                return self.getToken(NmrViewPKParser.W_name, i)

        def B_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.B_name)
            else:
                return self.getToken(NmrViewPKParser.B_name, i)

        def E_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.E_name)
            else:
                return self.getToken(NmrViewPKParser.E_name, i)

        def J_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.J_name)
            else:
                return self.getToken(NmrViewPKParser.J_name, i)

        def U_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.U_name)
            else:
                return self.getToken(NmrViewPKParser.U_name, i)

        def Vol(self):
            return self.getToken(NmrViewPKParser.Vol, 0)

        def Int(self):
            return self.getToken(NmrViewPKParser.Int, 0)

        def Stat(self):
            return self.getToken(NmrViewPKParser.Stat, 0)

        def Flag0(self):
            return self.getToken(NmrViewPKParser.Flag0, 0)

        def Comment(self):
            return self.getToken(NmrViewPKParser.Comment, 0)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def peak_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_2dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_2dContext,i)


        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_list_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_2d" ):
                listener.enterPeak_list_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_2d" ):
                listener.exitPeak_list_2d(self)




    def peak_list_2d(self):

        localctx = NmrViewPKParser.Peak_list_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_peak_list_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 74
            self.match(NmrViewPKParser.L_name)
            self.state = 75
            self.match(NmrViewPKParser.P_name)
            self.state = 76
            self.match(NmrViewPKParser.W_name)
            self.state = 77
            self.match(NmrViewPKParser.B_name)
            self.state = 78
            self.match(NmrViewPKParser.E_name)
            self.state = 79
            self.match(NmrViewPKParser.J_name)
            self.state = 80
            self.match(NmrViewPKParser.U_name)
            self.state = 81
            self.match(NmrViewPKParser.L_name)
            self.state = 82
            self.match(NmrViewPKParser.P_name)
            self.state = 83
            self.match(NmrViewPKParser.W_name)
            self.state = 84
            self.match(NmrViewPKParser.B_name)
            self.state = 85
            self.match(NmrViewPKParser.E_name)
            self.state = 86
            self.match(NmrViewPKParser.J_name)
            self.state = 87
            self.match(NmrViewPKParser.U_name)
            self.state = 88
            self.match(NmrViewPKParser.Vol)
            self.state = 89
            self.match(NmrViewPKParser.Int)
            self.state = 90
            self.match(NmrViewPKParser.Stat)
            self.state = 92
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==27:
                self.state = 91
                self.match(NmrViewPKParser.Comment)


            self.state = 94
            self.match(NmrViewPKParser.Flag0)
            self.state = 96
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 95
                self.match(NmrViewPKParser.RETURN)


            self.state = 99 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 98
                self.peak_2d()
                self.state = 101 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==2):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Integer)
            else:
                return self.getToken(NmrViewPKParser.Integer, i)

        def ENCLOSE_DATA(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.ENCLOSE_DATA)
            else:
                return self.getToken(NmrViewPKParser.ENCLOSE_DATA, i)

        def Float(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Float)
            else:
                return self.getToken(NmrViewPKParser.Float, i)

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Simple_name)
            else:
                return self.getToken(NmrViewPKParser.Simple_name, i)

        def jcoupling(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.JcouplingContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.JcouplingContext,i)


        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_2d" ):
                listener.enterPeak_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_2d" ):
                listener.exitPeak_2d(self)




    def peak_2d(self):

        localctx = NmrViewPKParser.Peak_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_peak_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 103
            self.match(NmrViewPKParser.Integer)
            self.state = 104
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 105
            self.match(NmrViewPKParser.Float)
            self.state = 106
            self.match(NmrViewPKParser.Float)
            self.state = 107
            self.match(NmrViewPKParser.Float)
            self.state = 108
            self.match(NmrViewPKParser.Simple_name)
            self.state = 109
            self.jcoupling()
            self.state = 110
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 111
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 112
            self.match(NmrViewPKParser.Float)
            self.state = 113
            self.match(NmrViewPKParser.Float)
            self.state = 114
            self.match(NmrViewPKParser.Float)
            self.state = 115
            self.match(NmrViewPKParser.Simple_name)
            self.state = 116
            self.jcoupling()
            self.state = 117
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 118
            self.match(NmrViewPKParser.Float)
            self.state = 119
            self.match(NmrViewPKParser.Float)
            self.state = 120
            self.match(NmrViewPKParser.Integer)
            self.state = 122
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==11:
                self.state = 121
                self.match(NmrViewPKParser.ENCLOSE_DATA)


            self.state = 124
            self.match(NmrViewPKParser.Integer)
            self.state = 125
            self.match(NmrViewPKParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def L_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.L_name)
            else:
                return self.getToken(NmrViewPKParser.L_name, i)

        def P_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.P_name)
            else:
                return self.getToken(NmrViewPKParser.P_name, i)

        def W_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.W_name)
            else:
                return self.getToken(NmrViewPKParser.W_name, i)

        def B_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.B_name)
            else:
                return self.getToken(NmrViewPKParser.B_name, i)

        def E_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.E_name)
            else:
                return self.getToken(NmrViewPKParser.E_name, i)

        def J_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.J_name)
            else:
                return self.getToken(NmrViewPKParser.J_name, i)

        def U_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.U_name)
            else:
                return self.getToken(NmrViewPKParser.U_name, i)

        def Vol(self):
            return self.getToken(NmrViewPKParser.Vol, 0)

        def Int(self):
            return self.getToken(NmrViewPKParser.Int, 0)

        def Stat(self):
            return self.getToken(NmrViewPKParser.Stat, 0)

        def Flag0(self):
            return self.getToken(NmrViewPKParser.Flag0, 0)

        def Comment(self):
            return self.getToken(NmrViewPKParser.Comment, 0)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def peak_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_3dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_3dContext,i)


        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_list_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_3d" ):
                listener.enterPeak_list_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_3d" ):
                listener.exitPeak_list_3d(self)




    def peak_list_3d(self):

        localctx = NmrViewPKParser.Peak_list_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_peak_list_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 127
            self.match(NmrViewPKParser.L_name)
            self.state = 128
            self.match(NmrViewPKParser.P_name)
            self.state = 129
            self.match(NmrViewPKParser.W_name)
            self.state = 130
            self.match(NmrViewPKParser.B_name)
            self.state = 131
            self.match(NmrViewPKParser.E_name)
            self.state = 132
            self.match(NmrViewPKParser.J_name)
            self.state = 133
            self.match(NmrViewPKParser.U_name)
            self.state = 134
            self.match(NmrViewPKParser.L_name)
            self.state = 135
            self.match(NmrViewPKParser.P_name)
            self.state = 136
            self.match(NmrViewPKParser.W_name)
            self.state = 137
            self.match(NmrViewPKParser.B_name)
            self.state = 138
            self.match(NmrViewPKParser.E_name)
            self.state = 139
            self.match(NmrViewPKParser.J_name)
            self.state = 140
            self.match(NmrViewPKParser.U_name)
            self.state = 141
            self.match(NmrViewPKParser.L_name)
            self.state = 142
            self.match(NmrViewPKParser.P_name)
            self.state = 143
            self.match(NmrViewPKParser.W_name)
            self.state = 144
            self.match(NmrViewPKParser.B_name)
            self.state = 145
            self.match(NmrViewPKParser.E_name)
            self.state = 146
            self.match(NmrViewPKParser.J_name)
            self.state = 147
            self.match(NmrViewPKParser.U_name)
            self.state = 148
            self.match(NmrViewPKParser.Vol)
            self.state = 149
            self.match(NmrViewPKParser.Int)
            self.state = 150
            self.match(NmrViewPKParser.Stat)
            self.state = 152
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==27:
                self.state = 151
                self.match(NmrViewPKParser.Comment)


            self.state = 154
            self.match(NmrViewPKParser.Flag0)
            self.state = 156
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 155
                self.match(NmrViewPKParser.RETURN)


            self.state = 159 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 158
                self.peak_3d()
                self.state = 161 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==2):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Integer)
            else:
                return self.getToken(NmrViewPKParser.Integer, i)

        def ENCLOSE_DATA(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.ENCLOSE_DATA)
            else:
                return self.getToken(NmrViewPKParser.ENCLOSE_DATA, i)

        def Float(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Float)
            else:
                return self.getToken(NmrViewPKParser.Float, i)

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Simple_name)
            else:
                return self.getToken(NmrViewPKParser.Simple_name, i)

        def jcoupling(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.JcouplingContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.JcouplingContext,i)


        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_3d" ):
                listener.enterPeak_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_3d" ):
                listener.exitPeak_3d(self)




    def peak_3d(self):

        localctx = NmrViewPKParser.Peak_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_peak_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 163
            self.match(NmrViewPKParser.Integer)
            self.state = 164
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 165
            self.match(NmrViewPKParser.Float)
            self.state = 166
            self.match(NmrViewPKParser.Float)
            self.state = 167
            self.match(NmrViewPKParser.Float)
            self.state = 168
            self.match(NmrViewPKParser.Simple_name)
            self.state = 169
            self.jcoupling()
            self.state = 170
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 171
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 172
            self.match(NmrViewPKParser.Float)
            self.state = 173
            self.match(NmrViewPKParser.Float)
            self.state = 174
            self.match(NmrViewPKParser.Float)
            self.state = 175
            self.match(NmrViewPKParser.Simple_name)
            self.state = 176
            self.jcoupling()
            self.state = 177
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 178
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 179
            self.match(NmrViewPKParser.Float)
            self.state = 180
            self.match(NmrViewPKParser.Float)
            self.state = 181
            self.match(NmrViewPKParser.Float)
            self.state = 182
            self.match(NmrViewPKParser.Simple_name)
            self.state = 183
            self.jcoupling()
            self.state = 184
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 185
            self.match(NmrViewPKParser.Float)
            self.state = 186
            self.match(NmrViewPKParser.Float)
            self.state = 187
            self.match(NmrViewPKParser.Integer)
            self.state = 189
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==11:
                self.state = 188
                self.match(NmrViewPKParser.ENCLOSE_DATA)


            self.state = 191
            self.match(NmrViewPKParser.Integer)
            self.state = 192
            self.match(NmrViewPKParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def L_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.L_name)
            else:
                return self.getToken(NmrViewPKParser.L_name, i)

        def P_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.P_name)
            else:
                return self.getToken(NmrViewPKParser.P_name, i)

        def W_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.W_name)
            else:
                return self.getToken(NmrViewPKParser.W_name, i)

        def B_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.B_name)
            else:
                return self.getToken(NmrViewPKParser.B_name, i)

        def E_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.E_name)
            else:
                return self.getToken(NmrViewPKParser.E_name, i)

        def J_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.J_name)
            else:
                return self.getToken(NmrViewPKParser.J_name, i)

        def U_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.U_name)
            else:
                return self.getToken(NmrViewPKParser.U_name, i)

        def Vol(self):
            return self.getToken(NmrViewPKParser.Vol, 0)

        def Int(self):
            return self.getToken(NmrViewPKParser.Int, 0)

        def Stat(self):
            return self.getToken(NmrViewPKParser.Stat, 0)

        def Flag0(self):
            return self.getToken(NmrViewPKParser.Flag0, 0)

        def Comment(self):
            return self.getToken(NmrViewPKParser.Comment, 0)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def peak_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_4dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_4dContext,i)


        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_list_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_4d" ):
                listener.enterPeak_list_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_4d" ):
                listener.exitPeak_list_4d(self)




    def peak_list_4d(self):

        localctx = NmrViewPKParser.Peak_list_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_peak_list_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 194
            self.match(NmrViewPKParser.L_name)
            self.state = 195
            self.match(NmrViewPKParser.P_name)
            self.state = 196
            self.match(NmrViewPKParser.W_name)
            self.state = 197
            self.match(NmrViewPKParser.B_name)
            self.state = 198
            self.match(NmrViewPKParser.E_name)
            self.state = 199
            self.match(NmrViewPKParser.J_name)
            self.state = 200
            self.match(NmrViewPKParser.U_name)
            self.state = 201
            self.match(NmrViewPKParser.L_name)
            self.state = 202
            self.match(NmrViewPKParser.P_name)
            self.state = 203
            self.match(NmrViewPKParser.W_name)
            self.state = 204
            self.match(NmrViewPKParser.B_name)
            self.state = 205
            self.match(NmrViewPKParser.E_name)
            self.state = 206
            self.match(NmrViewPKParser.J_name)
            self.state = 207
            self.match(NmrViewPKParser.U_name)
            self.state = 208
            self.match(NmrViewPKParser.L_name)
            self.state = 209
            self.match(NmrViewPKParser.P_name)
            self.state = 210
            self.match(NmrViewPKParser.W_name)
            self.state = 211
            self.match(NmrViewPKParser.B_name)
            self.state = 212
            self.match(NmrViewPKParser.E_name)
            self.state = 213
            self.match(NmrViewPKParser.J_name)
            self.state = 214
            self.match(NmrViewPKParser.U_name)
            self.state = 215
            self.match(NmrViewPKParser.L_name)
            self.state = 216
            self.match(NmrViewPKParser.P_name)
            self.state = 217
            self.match(NmrViewPKParser.W_name)
            self.state = 218
            self.match(NmrViewPKParser.B_name)
            self.state = 219
            self.match(NmrViewPKParser.E_name)
            self.state = 220
            self.match(NmrViewPKParser.J_name)
            self.state = 221
            self.match(NmrViewPKParser.U_name)
            self.state = 222
            self.match(NmrViewPKParser.Vol)
            self.state = 223
            self.match(NmrViewPKParser.Int)
            self.state = 224
            self.match(NmrViewPKParser.Stat)
            self.state = 226
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==27:
                self.state = 225
                self.match(NmrViewPKParser.Comment)


            self.state = 228
            self.match(NmrViewPKParser.Flag0)
            self.state = 230
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 229
                self.match(NmrViewPKParser.RETURN)


            self.state = 233 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 232
                self.peak_4d()
                self.state = 235 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==2):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Integer)
            else:
                return self.getToken(NmrViewPKParser.Integer, i)

        def ENCLOSE_DATA(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.ENCLOSE_DATA)
            else:
                return self.getToken(NmrViewPKParser.ENCLOSE_DATA, i)

        def Float(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Float)
            else:
                return self.getToken(NmrViewPKParser.Float, i)

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Simple_name)
            else:
                return self.getToken(NmrViewPKParser.Simple_name, i)

        def jcoupling(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.JcouplingContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.JcouplingContext,i)


        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_4d" ):
                listener.enterPeak_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_4d" ):
                listener.exitPeak_4d(self)




    def peak_4d(self):

        localctx = NmrViewPKParser.Peak_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_peak_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 237
            self.match(NmrViewPKParser.Integer)
            self.state = 238
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 239
            self.match(NmrViewPKParser.Float)
            self.state = 240
            self.match(NmrViewPKParser.Float)
            self.state = 241
            self.match(NmrViewPKParser.Float)
            self.state = 242
            self.match(NmrViewPKParser.Simple_name)
            self.state = 243
            self.jcoupling()
            self.state = 244
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 245
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 246
            self.match(NmrViewPKParser.Float)
            self.state = 247
            self.match(NmrViewPKParser.Float)
            self.state = 248
            self.match(NmrViewPKParser.Float)
            self.state = 249
            self.match(NmrViewPKParser.Simple_name)
            self.state = 250
            self.jcoupling()
            self.state = 251
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 252
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 253
            self.match(NmrViewPKParser.Float)
            self.state = 254
            self.match(NmrViewPKParser.Float)
            self.state = 255
            self.match(NmrViewPKParser.Float)
            self.state = 256
            self.match(NmrViewPKParser.Simple_name)
            self.state = 257
            self.jcoupling()
            self.state = 258
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 259
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 260
            self.match(NmrViewPKParser.Float)
            self.state = 261
            self.match(NmrViewPKParser.Float)
            self.state = 262
            self.match(NmrViewPKParser.Float)
            self.state = 263
            self.match(NmrViewPKParser.Simple_name)
            self.state = 264
            self.jcoupling()
            self.state = 265
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 266
            self.match(NmrViewPKParser.Float)
            self.state = 267
            self.match(NmrViewPKParser.Float)
            self.state = 268
            self.match(NmrViewPKParser.Integer)
            self.state = 270
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==11:
                self.state = 269
                self.match(NmrViewPKParser.ENCLOSE_DATA)


            self.state = 272
            self.match(NmrViewPKParser.Integer)
            self.state = 273
            self.match(NmrViewPKParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_wo_eju_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def L_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.L_name)
            else:
                return self.getToken(NmrViewPKParser.L_name, i)

        def P_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.P_name)
            else:
                return self.getToken(NmrViewPKParser.P_name, i)

        def W_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.W_name)
            else:
                return self.getToken(NmrViewPKParser.W_name, i)

        def B_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.B_name)
            else:
                return self.getToken(NmrViewPKParser.B_name, i)

        def Vol(self):
            return self.getToken(NmrViewPKParser.Vol, 0)

        def Int(self):
            return self.getToken(NmrViewPKParser.Int, 0)

        def Stat(self):
            return self.getToken(NmrViewPKParser.Stat, 0)

        def Flag0(self):
            return self.getToken(NmrViewPKParser.Flag0, 0)

        def Comment(self):
            return self.getToken(NmrViewPKParser.Comment, 0)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def peak_wo_eju_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_wo_eju_2dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_wo_eju_2dContext,i)


        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_list_wo_eju_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_wo_eju_2d" ):
                listener.enterPeak_list_wo_eju_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_wo_eju_2d" ):
                listener.exitPeak_list_wo_eju_2d(self)




    def peak_list_wo_eju_2d(self):

        localctx = NmrViewPKParser.Peak_list_wo_eju_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_peak_list_wo_eju_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 275
            self.match(NmrViewPKParser.L_name)
            self.state = 276
            self.match(NmrViewPKParser.P_name)
            self.state = 277
            self.match(NmrViewPKParser.W_name)
            self.state = 278
            self.match(NmrViewPKParser.B_name)
            self.state = 279
            self.match(NmrViewPKParser.L_name)
            self.state = 280
            self.match(NmrViewPKParser.P_name)
            self.state = 281
            self.match(NmrViewPKParser.W_name)
            self.state = 282
            self.match(NmrViewPKParser.B_name)
            self.state = 283
            self.match(NmrViewPKParser.Vol)
            self.state = 284
            self.match(NmrViewPKParser.Int)
            self.state = 285
            self.match(NmrViewPKParser.Stat)
            self.state = 287
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==27:
                self.state = 286
                self.match(NmrViewPKParser.Comment)


            self.state = 289
            self.match(NmrViewPKParser.Flag0)
            self.state = 291
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 290
                self.match(NmrViewPKParser.RETURN)


            self.state = 294 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 293
                self.peak_wo_eju_2d()
                self.state = 296 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==2):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_wo_eju_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Integer)
            else:
                return self.getToken(NmrViewPKParser.Integer, i)

        def ENCLOSE_DATA(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.ENCLOSE_DATA)
            else:
                return self.getToken(NmrViewPKParser.ENCLOSE_DATA, i)

        def Float(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Float)
            else:
                return self.getToken(NmrViewPKParser.Float, i)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_wo_eju_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_wo_eju_2d" ):
                listener.enterPeak_wo_eju_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_wo_eju_2d" ):
                listener.exitPeak_wo_eju_2d(self)




    def peak_wo_eju_2d(self):

        localctx = NmrViewPKParser.Peak_wo_eju_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_peak_wo_eju_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 298
            self.match(NmrViewPKParser.Integer)
            self.state = 299
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 300
            self.match(NmrViewPKParser.Float)
            self.state = 301
            self.match(NmrViewPKParser.Float)
            self.state = 302
            self.match(NmrViewPKParser.Float)
            self.state = 303
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 304
            self.match(NmrViewPKParser.Float)
            self.state = 305
            self.match(NmrViewPKParser.Float)
            self.state = 306
            self.match(NmrViewPKParser.Float)
            self.state = 307
            self.match(NmrViewPKParser.Float)
            self.state = 308
            self.match(NmrViewPKParser.Float)
            self.state = 309
            self.match(NmrViewPKParser.Integer)
            self.state = 311
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==11:
                self.state = 310
                self.match(NmrViewPKParser.ENCLOSE_DATA)


            self.state = 313
            self.match(NmrViewPKParser.Integer)
            self.state = 314
            self.match(NmrViewPKParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_wo_eju_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def L_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.L_name)
            else:
                return self.getToken(NmrViewPKParser.L_name, i)

        def P_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.P_name)
            else:
                return self.getToken(NmrViewPKParser.P_name, i)

        def W_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.W_name)
            else:
                return self.getToken(NmrViewPKParser.W_name, i)

        def B_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.B_name)
            else:
                return self.getToken(NmrViewPKParser.B_name, i)

        def Vol(self):
            return self.getToken(NmrViewPKParser.Vol, 0)

        def Int(self):
            return self.getToken(NmrViewPKParser.Int, 0)

        def Stat(self):
            return self.getToken(NmrViewPKParser.Stat, 0)

        def Flag0(self):
            return self.getToken(NmrViewPKParser.Flag0, 0)

        def Comment(self):
            return self.getToken(NmrViewPKParser.Comment, 0)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def peak_wo_eju_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_wo_eju_3dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_wo_eju_3dContext,i)


        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_list_wo_eju_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_wo_eju_3d" ):
                listener.enterPeak_list_wo_eju_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_wo_eju_3d" ):
                listener.exitPeak_list_wo_eju_3d(self)




    def peak_list_wo_eju_3d(self):

        localctx = NmrViewPKParser.Peak_list_wo_eju_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_peak_list_wo_eju_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 316
            self.match(NmrViewPKParser.L_name)
            self.state = 317
            self.match(NmrViewPKParser.P_name)
            self.state = 318
            self.match(NmrViewPKParser.W_name)
            self.state = 319
            self.match(NmrViewPKParser.B_name)
            self.state = 320
            self.match(NmrViewPKParser.L_name)
            self.state = 321
            self.match(NmrViewPKParser.P_name)
            self.state = 322
            self.match(NmrViewPKParser.W_name)
            self.state = 323
            self.match(NmrViewPKParser.B_name)
            self.state = 324
            self.match(NmrViewPKParser.L_name)
            self.state = 325
            self.match(NmrViewPKParser.P_name)
            self.state = 326
            self.match(NmrViewPKParser.W_name)
            self.state = 327
            self.match(NmrViewPKParser.B_name)
            self.state = 328
            self.match(NmrViewPKParser.Vol)
            self.state = 329
            self.match(NmrViewPKParser.Int)
            self.state = 330
            self.match(NmrViewPKParser.Stat)
            self.state = 332
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==27:
                self.state = 331
                self.match(NmrViewPKParser.Comment)


            self.state = 334
            self.match(NmrViewPKParser.Flag0)
            self.state = 336
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 335
                self.match(NmrViewPKParser.RETURN)


            self.state = 339 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 338
                self.peak_wo_eju_3d()
                self.state = 341 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==2):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_wo_eju_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Integer)
            else:
                return self.getToken(NmrViewPKParser.Integer, i)

        def ENCLOSE_DATA(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.ENCLOSE_DATA)
            else:
                return self.getToken(NmrViewPKParser.ENCLOSE_DATA, i)

        def Float(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Float)
            else:
                return self.getToken(NmrViewPKParser.Float, i)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_wo_eju_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_wo_eju_3d" ):
                listener.enterPeak_wo_eju_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_wo_eju_3d" ):
                listener.exitPeak_wo_eju_3d(self)




    def peak_wo_eju_3d(self):

        localctx = NmrViewPKParser.Peak_wo_eju_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_peak_wo_eju_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 343
            self.match(NmrViewPKParser.Integer)
            self.state = 344
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 345
            self.match(NmrViewPKParser.Float)
            self.state = 346
            self.match(NmrViewPKParser.Float)
            self.state = 347
            self.match(NmrViewPKParser.Float)
            self.state = 348
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 349
            self.match(NmrViewPKParser.Float)
            self.state = 350
            self.match(NmrViewPKParser.Float)
            self.state = 351
            self.match(NmrViewPKParser.Float)
            self.state = 352
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 353
            self.match(NmrViewPKParser.Float)
            self.state = 354
            self.match(NmrViewPKParser.Float)
            self.state = 355
            self.match(NmrViewPKParser.Float)
            self.state = 356
            self.match(NmrViewPKParser.Float)
            self.state = 357
            self.match(NmrViewPKParser.Float)
            self.state = 358
            self.match(NmrViewPKParser.Integer)
            self.state = 360
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==11:
                self.state = 359
                self.match(NmrViewPKParser.ENCLOSE_DATA)


            self.state = 362
            self.match(NmrViewPKParser.Integer)
            self.state = 363
            self.match(NmrViewPKParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_wo_eju_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def L_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.L_name)
            else:
                return self.getToken(NmrViewPKParser.L_name, i)

        def P_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.P_name)
            else:
                return self.getToken(NmrViewPKParser.P_name, i)

        def W_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.W_name)
            else:
                return self.getToken(NmrViewPKParser.W_name, i)

        def B_name(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.B_name)
            else:
                return self.getToken(NmrViewPKParser.B_name, i)

        def Vol(self):
            return self.getToken(NmrViewPKParser.Vol, 0)

        def Int(self):
            return self.getToken(NmrViewPKParser.Int, 0)

        def Stat(self):
            return self.getToken(NmrViewPKParser.Stat, 0)

        def Flag0(self):
            return self.getToken(NmrViewPKParser.Flag0, 0)

        def Comment(self):
            return self.getToken(NmrViewPKParser.Comment, 0)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def peak_wo_eju_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrViewPKParser.Peak_wo_eju_4dContext)
            else:
                return self.getTypedRuleContext(NmrViewPKParser.Peak_wo_eju_4dContext,i)


        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_list_wo_eju_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_wo_eju_4d" ):
                listener.enterPeak_list_wo_eju_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_wo_eju_4d" ):
                listener.exitPeak_list_wo_eju_4d(self)




    def peak_list_wo_eju_4d(self):

        localctx = NmrViewPKParser.Peak_list_wo_eju_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_peak_list_wo_eju_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 365
            self.match(NmrViewPKParser.L_name)
            self.state = 366
            self.match(NmrViewPKParser.P_name)
            self.state = 367
            self.match(NmrViewPKParser.W_name)
            self.state = 368
            self.match(NmrViewPKParser.B_name)
            self.state = 369
            self.match(NmrViewPKParser.L_name)
            self.state = 370
            self.match(NmrViewPKParser.P_name)
            self.state = 371
            self.match(NmrViewPKParser.W_name)
            self.state = 372
            self.match(NmrViewPKParser.B_name)
            self.state = 373
            self.match(NmrViewPKParser.L_name)
            self.state = 374
            self.match(NmrViewPKParser.P_name)
            self.state = 375
            self.match(NmrViewPKParser.W_name)
            self.state = 376
            self.match(NmrViewPKParser.B_name)
            self.state = 377
            self.match(NmrViewPKParser.L_name)
            self.state = 378
            self.match(NmrViewPKParser.P_name)
            self.state = 379
            self.match(NmrViewPKParser.W_name)
            self.state = 380
            self.match(NmrViewPKParser.B_name)
            self.state = 381
            self.match(NmrViewPKParser.Vol)
            self.state = 382
            self.match(NmrViewPKParser.Int)
            self.state = 383
            self.match(NmrViewPKParser.Stat)
            self.state = 385
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==27:
                self.state = 384
                self.match(NmrViewPKParser.Comment)


            self.state = 387
            self.match(NmrViewPKParser.Flag0)
            self.state = 389
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 388
                self.match(NmrViewPKParser.RETURN)


            self.state = 392 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 391
                self.peak_wo_eju_4d()
                self.state = 394 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==2):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_wo_eju_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Integer)
            else:
                return self.getToken(NmrViewPKParser.Integer, i)

        def ENCLOSE_DATA(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.ENCLOSE_DATA)
            else:
                return self.getToken(NmrViewPKParser.ENCLOSE_DATA, i)

        def Float(self, i:int=None):
            if i is None:
                return self.getTokens(NmrViewPKParser.Float)
            else:
                return self.getToken(NmrViewPKParser.Float, i)

        def RETURN(self):
            return self.getToken(NmrViewPKParser.RETURN, 0)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_peak_wo_eju_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_wo_eju_4d" ):
                listener.enterPeak_wo_eju_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_wo_eju_4d" ):
                listener.exitPeak_wo_eju_4d(self)




    def peak_wo_eju_4d(self):

        localctx = NmrViewPKParser.Peak_wo_eju_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_peak_wo_eju_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 396
            self.match(NmrViewPKParser.Integer)
            self.state = 397
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 398
            self.match(NmrViewPKParser.Float)
            self.state = 399
            self.match(NmrViewPKParser.Float)
            self.state = 400
            self.match(NmrViewPKParser.Float)
            self.state = 401
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 402
            self.match(NmrViewPKParser.Float)
            self.state = 403
            self.match(NmrViewPKParser.Float)
            self.state = 404
            self.match(NmrViewPKParser.Float)
            self.state = 405
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 406
            self.match(NmrViewPKParser.Float)
            self.state = 407
            self.match(NmrViewPKParser.Float)
            self.state = 408
            self.match(NmrViewPKParser.Float)
            self.state = 409
            self.match(NmrViewPKParser.ENCLOSE_DATA)
            self.state = 410
            self.match(NmrViewPKParser.Float)
            self.state = 411
            self.match(NmrViewPKParser.Float)
            self.state = 412
            self.match(NmrViewPKParser.Float)
            self.state = 413
            self.match(NmrViewPKParser.Float)
            self.state = 414
            self.match(NmrViewPKParser.Float)
            self.state = 415
            self.match(NmrViewPKParser.Integer)
            self.state = 417
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==11:
                self.state = 416
                self.match(NmrViewPKParser.ENCLOSE_DATA)


            self.state = 419
            self.match(NmrViewPKParser.Integer)
            self.state = 420
            self.match(NmrViewPKParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LabelContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Float_LA(self):
            return self.getToken(NmrViewPKParser.Float_LA, 0)

        def Simple_name_LA(self):
            return self.getToken(NmrViewPKParser.Simple_name_LA, 0)

        def ENCLOSE_DATA_LA(self):
            return self.getToken(NmrViewPKParser.ENCLOSE_DATA_LA, 0)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_label

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLabel" ):
                listener.enterLabel(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLabel" ):
                listener.exitLabel(self)




    def label(self):

        localctx = NmrViewPKParser.LabelContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_label)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 422
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & 10200547328) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class JcouplingContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Float(self):
            return self.getToken(NmrViewPKParser.Float, 0)

        def Simple_name(self):
            return self.getToken(NmrViewPKParser.Simple_name, 0)

        def ENCLOSE_DATA(self):
            return self.getToken(NmrViewPKParser.ENCLOSE_DATA, 0)

        def getRuleIndex(self):
            return NmrViewPKParser.RULE_jcoupling

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterJcoupling" ):
                listener.enterJcoupling(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitJcoupling" ):
                listener.exitJcoupling(self)




    def jcoupling(self):

        localctx = NmrViewPKParser.JcouplingContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_jcoupling)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 424
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & 2312) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx








# Generated from XeasyPROTParser.g4 by ANTLR 4.13.0
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,11,26,2,0,7,0,2,1,7,1,2,2,7,2,1,0,3,0,8,8,0,1,0,4,0,11,8,0,11,
        0,12,0,12,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,2,1,2,0,0,3,
        0,2,4,0,1,2,0,1,1,6,6,24,0,7,1,0,0,0,2,16,1,0,0,0,4,23,1,0,0,0,6,
        8,5,8,0,0,7,6,1,0,0,0,7,8,1,0,0,0,8,10,1,0,0,0,9,11,3,2,1,0,10,9,
        1,0,0,0,11,12,1,0,0,0,12,10,1,0,0,0,12,13,1,0,0,0,13,14,1,0,0,0,
        14,15,5,0,0,1,15,1,1,0,0,0,16,17,5,1,0,0,17,18,5,2,0,0,18,19,5,2,
        0,0,19,20,5,6,0,0,20,21,3,4,2,0,21,22,5,8,0,0,22,3,1,0,0,0,23,24,
        7,0,0,0,24,5,1,0,0,0,2,7,12
    ]

class XeasyPROTParser ( Parser ):

    grammarFileName = "XeasyPROTParser.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [  ]

    symbolicNames = [ "<INVALID>", "Integer", "Float", "SHARP_COMMENT", 
                      "EXCLM_COMMENT", "SMCLN_COMMENT", "Simple_name", "SPACE", 
                      "RETURN", "ENCLOSE_COMMENT", "SECTION_COMMENT", "LINE_COMMENT" ]

    RULE_xeasy_prot = 0
    RULE_prot = 1
    RULE_residue = 2

    ruleNames =  [ "xeasy_prot", "prot", "residue" ]

    EOF = Token.EOF
    Integer=1
    Float=2
    SHARP_COMMENT=3
    EXCLM_COMMENT=4
    SMCLN_COMMENT=5
    Simple_name=6
    SPACE=7
    RETURN=8
    ENCLOSE_COMMENT=9
    SECTION_COMMENT=10
    LINE_COMMENT=11

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.13.0")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class Xeasy_protContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EOF(self):
            return self.getToken(XeasyPROTParser.EOF, 0)

        def RETURN(self):
            return self.getToken(XeasyPROTParser.RETURN, 0)

        def prot(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(XeasyPROTParser.ProtContext)
            else:
                return self.getTypedRuleContext(XeasyPROTParser.ProtContext,i)


        def getRuleIndex(self):
            return XeasyPROTParser.RULE_xeasy_prot

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXeasy_prot" ):
                listener.enterXeasy_prot(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXeasy_prot" ):
                listener.exitXeasy_prot(self)




    def xeasy_prot(self):

        localctx = XeasyPROTParser.Xeasy_protContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_xeasy_prot)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 7
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==8:
                self.state = 6
                self.match(XeasyPROTParser.RETURN)


            self.state = 10 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 9
                self.prot()
                self.state = 12 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==1):
                    break

            self.state = 14
            self.match(XeasyPROTParser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ProtContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self):
            return self.getToken(XeasyPROTParser.Integer, 0)

        def Float(self, i:int=None):
            if i is None:
                return self.getTokens(XeasyPROTParser.Float)
            else:
                return self.getToken(XeasyPROTParser.Float, i)

        def Simple_name(self):
            return self.getToken(XeasyPROTParser.Simple_name, 0)

        def residue(self):
            return self.getTypedRuleContext(XeasyPROTParser.ResidueContext,0)


        def RETURN(self):
            return self.getToken(XeasyPROTParser.RETURN, 0)

        def getRuleIndex(self):
            return XeasyPROTParser.RULE_prot

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProt" ):
                listener.enterProt(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProt" ):
                listener.exitProt(self)




    def prot(self):

        localctx = XeasyPROTParser.ProtContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_prot)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 16
            self.match(XeasyPROTParser.Integer)
            self.state = 17
            self.match(XeasyPROTParser.Float)
            self.state = 18
            self.match(XeasyPROTParser.Float)
            self.state = 19
            self.match(XeasyPROTParser.Simple_name)
            self.state = 20
            self.residue()
            self.state = 21
            self.match(XeasyPROTParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ResidueContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self):
            return self.getToken(XeasyPROTParser.Integer, 0)

        def Simple_name(self):
            return self.getToken(XeasyPROTParser.Simple_name, 0)

        def getRuleIndex(self):
            return XeasyPROTParser.RULE_residue

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterResidue" ):
                listener.enterResidue(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitResidue" ):
                listener.exitResidue(self)




    def residue(self):

        localctx = XeasyPROTParser.ResidueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_residue)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 23
            _la = self._input.LA(1)
            if not(_la==1 or _la==6):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx





